Package: BayesERtools
Type: Package
Title: Bayesian Exposure-Response Analysis Tools
Version: 0.2.6
Authors@R: 
    c(person("Kenta", "Yoshida", , "yoshida.kenta.6@gmail.com", role = c("aut", "cre"),
             comment = c(ORCID = "0000-0003-4967-3831")),
      person("François", "Mercier", , "francois.mercier@roche.com", role = c("aut"),
             comment = c(ORCID = "0000-0002-5685-1408")),
      person("Danielle", "Navarro", , "djnavarro@protonmail.com", c("aut"),
             comment = c(ORCID = "0000-0001-7648-6578")),
      person("Genentech, Inc.", role = "cph")
      )
Maintainer: Kenta Yoshida <yoshida.kenta.6@gmail.com>
Description: Suite of tools that facilitate
    exposure-response analysis using Bayesian methods. The package
    provides a streamlined workflow for fitting types of models that are
    commonly used in exposure-response analysis - linear and Emax for continuous
    endpoints, logistic linear and logistic Emax for binary endpoints, as well
    as performing simulation and visualization. Learn more about the workflow
    at <https://genentech.github.io/BayesERbook/>.
License: Apache License 2.0
Encoding: UTF-8
LazyData: true
Depends: R (>= 4.1)
URL: https://genentech.github.io/BayesERtools/,
        https://genentech.github.io/BayesERbook/
Config/testthat/edition: 3
RoxygenNote: 7.3.3
Imports: dplyr, tidyr, purrr, ggplot2, gt, cli, rlang, rstanarm,
        rstanemax (>= 0.1.9), rstantools, loo, ggdist, posterior
Suggests: testthat (>= 3.0.0), covr, knitr, rmarkdown, rstan,
        htmltools, digest, ggforce, xgxr, scales, readr, bayestestR,
        patchwork, projpred, rsample, yardstick
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-06-13 05:28:34 UTC; yoshidk6
Author: Kenta Yoshida [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-4967-3831>),
  François Mercier [aut] (ORCID: <https://orcid.org/0000-0002-5685-1408>),
  Danielle Navarro [aut] (ORCID: <https://orcid.org/0000-0001-7648-6578>),
  Genentech, Inc. [cph]
Repository: CRAN
Date/Publication: 2026-06-13 06:10:08 UTC
Built: R 4.5.2; ; 2026-06-13 10:16:06 UTC; unix
