# Generated by roxygen2: do not edit by hand

S3method(as_draws,ermod)
S3method(as_draws_array,ermod)
S3method(as_draws_df,ermod)
S3method(as_draws_list,ermod)
S3method(as_draws_matrix,ermod)
S3method(as_draws_rvars,ermod)
S3method(bayestestR::p_direction,ermod_bin)
S3method(coef,ermod)
S3method(extract_data,ermod)
S3method(extract_data,ersim)
S3method(extract_data,ersim_med_qi)
S3method(extract_exp_sel_comp,ermod_exp_sel)
S3method(extract_exp_sel_list_model,ermod_exp_sel)
S3method(extract_mod,ermod)
S3method(extract_var_cov,ermod)
S3method(extract_var_cov,ersim)
S3method(extract_var_cov,ersim_med_qi)
S3method(extract_var_exposure,ermod)
S3method(extract_var_exposure,ersim)
S3method(extract_var_exposure,ersim_med_qi)
S3method(extract_var_resp,ermod)
S3method(extract_var_resp,ersim)
S3method(extract_var_resp,ersim_med_qi)
S3method(extract_var_selected,ermod_cov_sel)
S3method(kfold,ermod)
S3method(loo,ermod)
S3method(loo,ermod_bin_emax)
S3method(loo,ermod_emax)
S3method(plot,ermod_bin)
S3method(plot,ermod_cov_sel)
S3method(plot,ermod_exp_sel)
S3method(plot,ersim)
S3method(plot,ersim_med_qi)
S3method(plot_coveff,coveffsim)
S3method(plot_coveff,ermod)
S3method(plot_er,ermod)
S3method(plot_er,ersim)
S3method(plot_er,ersim_med_qi)
S3method(print,er_plot_components)
S3method(print,ermod)
S3method(print,ermod_cov_sel)
S3method(print,ermod_exp_sel)
S3method(print,kfold_ermod)
S3method(prior_summary,ermod)
S3method(summary,ermod)
export(.dev_ermod_refmodel)
export(.select_cov_projpred)
export(as_draws)
export(as_draws_array)
export(as_draws_df)
export(as_draws_list)
export(as_draws_matrix)
export(as_draws_rvars)
export(build_spec_coveff)
export(build_spec_coveff_one_variable)
export(calc_ersim_med_qi)
export(combine_er_components)
export(dev_ermod_bin)
export(dev_ermod_bin_cov_sel)
export(dev_ermod_bin_emax)
export(dev_ermod_bin_emax_exp_sel)
export(dev_ermod_bin_exp_sel)
export(dev_ermod_emax)
export(dev_ermod_emax_exp_sel)
export(dev_ermod_lin)
export(dev_ermod_lin_cov_sel)
export(dev_ermod_lin_exp_sel)
export(eval_ermod)
export(extract_coef_exp_ci)
export(extract_data)
export(extract_exp_sel_comp)
export(extract_exp_sel_list_model)
export(extract_kfold_loo)
export(extract_mod)
export(extract_var_cov)
export(extract_var_exposure)
export(extract_var_resp)
export(extract_var_selected)
export(kfold)
export(loo)
export(plot_coveff)
export(plot_er)
export(plot_er_exp_sel)
export(plot_er_gof)
export(plot_submod_performance)
export(plot_var_ranking)
export(print_coveff)
export(prior_summary)
export(replace_spec_coveff)
export(sim_coveff)
export(sim_er)
export(sim_er_curve)
export(sim_er_curve_marg)
export(sim_er_new_exp)
export(sim_er_new_exp_marg)
importFrom(loo,kfold)
importFrom(loo,loo)
importFrom(posterior,as_draws)
importFrom(posterior,as_draws_array)
importFrom(posterior,as_draws_df)
importFrom(posterior,as_draws_list)
importFrom(posterior,as_draws_matrix)
importFrom(posterior,as_draws_rvars)
importFrom(rstanarm,prior_summary)
